instrumenttools.Marimba
=======================

.. inheritance-diagram:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba
   :private-bases:

.. autoclass:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.default_instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.default_short_instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.effective_context

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.format

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.interval_of_transposition

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.is_primary_instrument

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.is_secondary_instrument

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.is_transposing

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.start_component

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.target_context

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.traditional_pitch_range

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.all_clefs

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.instrument_name_markup

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.pitch_range

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.primary_clefs

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.short_instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.short_instrument_name_markup

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.sounding_pitch_of_fingered_middle_c

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.attach

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.detach

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.get_default_performer_name

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.get_performer_names

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__call__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__delattr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__eq__

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__hash__

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__ne__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__repr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__setattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__str__

    Inherited from `__builtin__.object`
